pub enum SocketType {
TCP,
UDP,
RawUDP,
}Expand description
Determines the socket protocol to be used.
Variants
TCP
Socket type with features like retransmission and message ordering making it most reliable. Best to use if you don not care much about the specific details.
UDP
Socket type with limited safety features making it inherently unreliable. Best to use this if you want to define a fast low level protocol.
RawUDP
Socket type with limited safety but with a wider range of function special to UDP. Only use this if you need features like multi casting and high flexibility.