Defines messages able to be sent between devices
Traits
- Deserialize
- A data structure that can be deserialized from any data format supported by Serde.
- Sendable
- Type able to be sent between devices
- Serialize
- A data structure that can be serialized into any data format supported by Serde.